@@ -162,22 +162,16 @@ comments_get_comment_filename (const char *source,
 	source_real = g_strdup (source);
 
 	if (resolve_symlinks) {
-		char           *parent;
-		char           *parent_resolved;
+		char           *resolved = NULL;
 		GnomeVFSResult  result;
 
-		parent = remove_level_from_path (source);
-		result = resolve_all_symlinks (parent, &parent_resolved);
-		g_free (parent);
+		result = resolve_all_symlinks (source_real, &resolved);
 
 		if (result == GNOME_VFS_OK) { 
 			g_free (source_real);
-			source_real = g_strconcat (parent_resolved, 
-						   "/",
-						   file_name_from_path (source),
-						   NULL);
-			g_free (parent_resolved);
-		} 
+			source_real = resolved;
+		} else
+			g_free (resolved);
 	}
 
 	directory = remove_level_from_path (source_real);
@@ -192,15 +186,15 @@ comments_get_comment_filename (const char *source,
 			    COMMENT_EXT, 
 			    NULL);
 
+	if (!unescape) {
+		char *escaped_path = gnome_vfs_escape_path_string (path);
+		g_free (path);
+		path = escaped_path;
+	}
+
 	g_free (directory);
 	g_free (source_real);
 
-	if (unescape) {
-		char *unesc_path = gnome_vfs_unescape_string (path, NULL);
-		g_free (path);
-		path = unesc_path;
-	}
-
 	return path;
 }
 
@@ -220,9 +214,6 @@ comments_get_comment_dir (const char *directory,
 		result = resolve_all_symlinks (directory, &directory_resolved);
 		if (result == GNOME_VFS_OK) 
 			directory_real = directory_resolved;
-		else
-			g_print ("ERROR: %s\n", gnome_vfs_result_to_string (result));
-		g_print ("RESOLVED: %s\n", directory_resolved);
 	}
 
 	if (directory_real == NULL)
@@ -630,7 +621,9 @@ save_comment (const char  *filename,
 	/* Write to disk. */
 
 	comment_file = comments_get_comment_filename (filename, TRUE, TRUE);
+
 	dest_dir = remove_level_from_path (comment_file);
+
 	if (ensure_dir_exists (dest_dir, 0700)) {
 		xmlSetDocCompressMode (doc, 3);
 		xmlSaveFile (comment_file, doc);
@@ -752,11 +745,11 @@ comments_get_comment_as_string (CommentData *data,
 				char        *sep2)
 {
 	char      *as_string = NULL;
-	char       time_txt[50];
+	char       time_txt[50] = "";
 	char      *utf8_time_txt = NULL;
 	struct tm *tm;
 
-	if (data == NULL) 
+	if (data == NULL)
 		return NULL;
  
 	if (data->time != 0) {
