@@ -150,6 +150,7 @@ static EnumStringTable check_size_table [] = {
 static EnumStringTable slideshow_direction_table [] = {
 	{ GTH_DIRECTION_FORWARD, "forward" },
 	{ GTH_DIRECTION_REVERSE, "backward" },
+	{ GTH_DIRECTION_RANDOM,  "random" },
 	{ 0, NULL }
 };
 
@@ -240,7 +241,15 @@ preferences_init (void)
         g_object_unref (client);
 
 	preferences.startup_location = NULL;
-	preferences_set_startup_location (eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL));
+
+	if (eel_gconf_get_boolean (PREF_USE_STARTUP_LOCATION, FALSE) ||
+	    eel_gconf_get_boolean (PREF_GO_TO_LAST_LOCATION, FALSE))
+		preferences_set_startup_location (eel_gconf_get_path (PREF_STARTUP_LOCATION, NULL));
+	else {
+		char *current = g_get_current_dir ();
+		preferences_set_startup_location (current);
+		g_free (current);
+	}
 }
 
 
@@ -539,3 +548,36 @@ pref_get_view_mode (void)
 
 	return GTH_VIEW_MODE_VOID;
 }
+
+
+GthToolbarStyle
+pref_get_real_toolbar_style (void)
+{
+	GthToolbarStyle toolbar_style;
+
+	toolbar_style = pref_get_toolbar_style();
+
+	if (toolbar_style == GTH_TOOLBAR_STYLE_SYSTEM) {
+		char *system_style;
+
+		system_style = eel_gconf_get_string ("/desktop/gnome/interface/toolbar_style", "system");
+
+		if (system_style == NULL)
+			toolbar_style = GTH_TOOLBAR_STYLE_TEXT_BELOW;
+		else if (strcmp (system_style, "both") == 0)
+			toolbar_style = GTH_TOOLBAR_STYLE_TEXT_BELOW;
+		else if (strcmp (system_style, "both_horiz") == 0)
+			toolbar_style = GTH_TOOLBAR_STYLE_TEXT_BESIDE;
+		else if (strcmp (system_style, "icons") == 0)
+			toolbar_style = GTH_TOOLBAR_STYLE_ICONS;
+		else if (strcmp (system_style, "text") == 0)
+			toolbar_style = GTH_TOOLBAR_STYLE_TEXT;
+		else
+			toolbar_style = GTH_TOOLBAR_STYLE_TEXT_BELOW;
+
+		g_free (system_style);
+	}
+
+	return toolbar_style;
+}
+
